@@ -3,9 +3,10 @@ package HTTP::Request::Common;
 use strict;
 use warnings;
 
-our $VERSION = '6.41';
+our $VERSION = '6.42';
 
 our $DYNAMIC_FILE_UPLOAD ||= 0;  # make it defined (don't know why)
+our $READ_BUFFER_SIZE      = 8192;
 
 use Exporter 5.57 'import';
 
@@ -253,7 +254,7 @@ sub form_data   # RFC1867
                     binmode($fh);
                 }
 		my $buflength = length $buf;
-		my $n = read($fh, $buf, 2048, $buflength);
+		my $n = read($fh, $buf, $READ_BUFFER_SIZE, $buflength);
 		if ($n) {
 		    $buflength += $n;
 		    unshift(@parts, ["", $fh]);
@@ -314,7 +315,7 @@ HTTP::Request::Common - Construct common HTTP::Request objects
 
 =head1 VERSION
 
-version 6.41
+version 6.42
 
 =head1 SYNOPSIS
 
